@@ -37,6 +37,7 @@ use base 'Module::Build';
 use Carp;
 use File::Spec;
 use Config;
+use Alien::SDL::ConfigData;
 
 # Module::Build doesn't seem to have a way to use separate flags for separate
 # XS files, so here's the override that makes separate files build correctly:
@@ -44,9 +45,6 @@ sub process_xs
 {
 	my ($self, $file) = @_;
 
-	#TODO: call this in MSWin32::process_xs
-	$file =~ s/\\/\//g if( $^O eq 'MSWin32' );
-
 	my $properties                   = $self->{properties};
 	my $file_args                    = $self->notes( 'file_flags' )->{$file};
 
@@ -120,8 +118,14 @@ sub set_file_flags
 	my %file_flags;
 	my %build_systems = %{$self->notes('build_systems')};
 
-	my $debug = " "; 
-        $debug = ' -g -rdynamic ' unless $^O =~ /(win|darwin)/i;
+	#TODO:  Search for execinfo.h signal.h and turn this on.
+	#	This should also be turned on only during CPAN tests
+	my $debug = ' -DNOSIGCATCH '; #default until headers found
+	if ( Alien::SDL->check_header(qw(execinfo.h signal.h)) && $ENV{AUTOMATED_TESTING})
+	{
+	   $debug .= ' -g -rdynamic ' unless ($^O =~ /(win|darwin|bsd)/i);
+
+	}
 
 	while (my ($subsystem, $param) = each %build_systems )
 	{
@@ -144,6 +148,13 @@ sub set_file_flags
 }
 
 # override the following functions in My::Builder::<platform> if necessary
+sub ACTION_build {
+	my $self = shift;
+
+	printf("[Alien::SDL] Build option used:\n\t%s\n", ${Alien::SDL::ConfigData->config('build_params')}{'title'} || 'n.a.');
+	$self->SUPER::ACTION_build;
+}
+
 # both special to MacOS/Darwin, somebody should review whether it is still necessary
 sub special_build_settings { }
 sub build_bundle { }
@@ -165,17 +176,10 @@ sub ACTION_install {
 }
 
 sub ACTION_test {
-     my ($self) = @_;
-     $self->depends_on('build');
-     if ( $^O =~ /darwin/ )
-     {
-	$self->build_test();
-     }
-     else
-     {
-	$self->SUPER::ACTION_test();
-     }
+	my ($self) = @_;
+	$self->depends_on('build');
 
+	$self->SUPER::ACTION_test();
 }
 
 1;
