@@ -1,16 +1,12 @@
 package SDL::CD;
 use strict;
 use warnings;
-use vars qw($VERSION $XS_VERSION @ISA @EXPORT @EXPORT_OK);
+use vars qw(@ISA @EXPORT @EXPORT_OK);
 require Exporter;
 require DynaLoader;
 use SDL::Constants ':SDL::CDROM';
 our @ISA = qw(Exporter DynaLoader);
 
-our $VERSION    = '2.541_10';
-our $XS_VERSION = $VERSION;
-$VERSION = eval $VERSION;
-
 use SDL::Internal::Loader;
 internal_load_dlls(__PACKAGE__);
 
@@ -26,23 +22,22 @@ our %EXPORT_TAGS = (
 );
 
 # Conversion functions from frames to Minute/Second/Frames and vice versa
-sub FRAMES_TO_MSF {
+sub FRAMES_TO_MSF{
 	my $frames = shift;
-	my $F      = $frames % CD_FPS;
+	my $F = $frames % CD_FPS;
 	$frames /= CD_FPS;
 	my $S = $frames % 60;
 	$frames /= 60;
 	my $M = $frames;
-
-	return ( $M, $S, $F );
+	
+	return ($M, $S, $F);
 }
-
-sub MSF_TO_FRAMES {
+sub MSF_TO_FRAMES{
 	my $M = shift;
 	my $S = shift;
 	my $F = shift;
 
-	return ( $M * 60 * CD_FPS + $S * CD_FPS + $F );
+	return ($M * 60 * CD_FPS + $S * CD_FPS + $F);
 }
 
 1;
