@@ -1,15 +1,11 @@
 package SDL::Internal::Loader;
 use strict;
 use warnings;
-use vars qw($VERSION @ISA @EXPORT @LIBREFS);
 require Exporter;
-our @ISA     = qw(Exporter);
-our @EXPORT  = qw(internal_load_dlls);
+our @ISA = qw(Exporter);
+our @EXPORT = qw(internal_load_dlls);
 our @LIBREFS = ();
 
-our $VERSION = '2.541_10';
-$VERSION = eval $VERSION;
-
 use SDL::ConfigData;
 use Alien::SDL;
 
@@ -33,24 +29,28 @@ use Alien::SDL;
 # internal_load_dlls(PACKAGE);
 
 sub internal_load_dlls($) {
-	my $package = shift;
-	### check if some ld_shlib_map is defined
-	my $shlib_map = Alien::SDL->config('ld_shlib_map');
-	return unless $shlib_map; # empty shlib_map, nothing to do
+  my $package = shift;
+  ### check if some ld_shlib_map is defined
+  my $shlib_map = Alien::SDL->config('ld_shlib_map');
+  return unless $shlib_map; # empty shlib_map, nothing to do
 
-	### get list of lib nicknames based on packagename
-	my $lib_nick = SDL::ConfigData->config('SDL_lib_translate')->{$package};
-	return unless $lib_nick;  # no need to load anything
+  ### get list of lib nicknames based on packagename
+  my $lib_nick = SDL::ConfigData->config('SDL_lib_translate')->{$package};
+  return unless $lib_nick; # no need to load anything
 
-	### let us load the corresponding shlibs (*.dll|*.so)
-	require DynaLoader;
-	foreach my $n (@$lib_nick) {
-		my $file = $shlib_map->{$n};
-		next unless $file && -e $file;
-		my $libref = DynaLoader::dl_load_file( $file, 0 );
-		push( @DynaLoader::dl_librefs, $libref ) if $libref;
-		push( @LIBREFS,                $libref ) if $libref;
-	}
+  ### let us load the corresponding shlibs (*.dll|*.so)
+  require DynaLoader;  
+  foreach my $n (@$lib_nick) {
+    my $file = $shlib_map->{$n};
+    if($file && -e $file) {
+      my $libref = DynaLoader::dl_load_file($file, 0);
+      push(@DynaLoader::dl_librefs, $libref) if $libref;
+      push (@LIBREFS, $libref) if $libref;
+    }
+    else {
+      print(STDERR "###ERROR### shared object file '$file' for '$n' not found.\n");
+    }
+  }
 }
 
 1;
